@@ -4,7 +4,7 @@
 
     config_generator.h - this file is part of Gerbera.
 
-    Copyright (C) 2016-2025 Gerbera Contributors
+    Copyright (C) 2016-2026 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -163,7 +163,7 @@ protected:
     std::shared_ptr<pugi::xml_node> setXmlValue(const std::shared_ptr<pugi::xml_node>& parent, ConfigVal option, const std::string& value);
 
     /// @brief dictionary with section names
-    static std::map<GeneratorSections, std::string_view> sections;
+    static std::map<GeneratorSections, std::string> sections;
 };
 
 #endif // GERBERA_CONFIG_GENERATOR_H
