@@ -11,7 +11,7 @@
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
 
-    Copyright (C) 2016-2025 Gerbera Contributors
+    Copyright (C) 2016-2026 Gerbera Contributors
 
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -50,6 +50,7 @@
 #include "util/tools.h"
 
 #include <numeric>
+#include <pugixml.hpp>
 #include <sstream>
 
 #if defined(HAVE_NL_LANGINFO) && defined(HAVE_SETLOCALE)
@@ -66,7 +67,6 @@ ConfigManager::ConfigManager(
     : definition(std::move(definition))
     , filename(std::move(filename))
     , dataDir(std::move(dataDir))
-    , xmlDoc(std::make_unique<pugi::xml_document>())
 {
     options = std::vector<std::shared_ptr<ConfigOption>>(to_underlying(ConfigVal::MAX));
     GrbLogger::Logger.setDebugLogging(debug);
@@ -137,14 +137,14 @@ void ConfigManager::load(const fs::path& userHome)
     auto self = getSelf();
 
     log_info("Loading configuration from: {}", filename.string());
-    pugi::xml_parse_result result = xmlDoc->load_file(filename.c_str());
+    pugi::xml_parse_result result = xmlDoc.load_file(filename.c_str());
     if (result.status != pugi::xml_parse_status::status_ok) {
         throw ConfigParseException(result.description());
     }
 
     log_info("Parsing configuration...");
 
-    auto root = xmlDoc->document_element();
+    auto root = xmlDoc.document_element();
 
     getAllNodes(root, false);
 
@@ -211,13 +211,13 @@ void ConfigManager::load(const fs::path& userHome)
             setOption(root, option);
 
         co = definition->findConfigSetup(ConfigVal::SERVER_STORAGE_MYSQL_INIT_SQL_FILE);
-        co->setDefaultValue(dataDir / "mysql.sql");
+        co->setDefaultValue(dataDir / MY_INIT_FILE);
         co->makeOption(root, self);
         co = definition->findConfigSetup(ConfigVal::SERVER_STORAGE_MYSQL_UPGRADE_FILE);
-        co->setDefaultValue(dataDir / "mysql-upgrade.xml");
+        co->setDefaultValue(dataDir / MY_UPGR_FILE);
         co->makeOption(root, self);
         co = definition->findConfigSetup(ConfigVal::SERVER_STORAGE_MYSQL_DROP_FILE);
-        co->setDefaultValue(dataDir / "mysql-drop.sql");
+        co->setDefaultValue(dataDir / MY_DROP_FILE);
         co->makeOption(root, self);
         dbDriver = DB_DRIVER_MYSQL;
     }
@@ -230,13 +230,13 @@ void ConfigManager::load(const fs::path& userHome)
             setOption(root, option);
 
         co = definition->findConfigSetup(ConfigVal::SERVER_STORAGE_PGSQL_INIT_SQL_FILE);
-        co->setDefaultValue(dataDir / "postgres.sql");
+        co->setDefaultValue(dataDir / PG_INIT_FILE);
         co->makeOption(root, self);
         co = definition->findConfigSetup(ConfigVal::SERVER_STORAGE_PGSQL_UPGRADE_FILE);
-        co->setDefaultValue(dataDir / "postgres-upgrade.xml");
+        co->setDefaultValue(dataDir / PG_UPGR_FILE);
         co->makeOption(root, self);
         co = definition->findConfigSetup(ConfigVal::SERVER_STORAGE_PGSQL_DROP_FILE);
-        co->setDefaultValue(dataDir / "postgres-drop.sql");
+        co->setDefaultValue(dataDir / PG_DROP_FILE);
         co->makeOption(root, self);
         dbDriver = DB_DRIVER_POSTGRES;
     }
@@ -248,13 +248,13 @@ void ConfigManager::load(const fs::path& userHome)
             setOption(root, option);
 
         co = definition->findConfigSetup(ConfigVal::SERVER_STORAGE_SQLITE_INIT_SQL_FILE);
-        co->setDefaultValue(dataDir / "sqlite3.sql");
+        co->setDefaultValue(dataDir / SL_INIT_FILE);
         co->makeOption(root, self);
         co = definition->findConfigSetup(ConfigVal::SERVER_STORAGE_SQLITE_UPGRADE_FILE);
-        co->setDefaultValue(dataDir / "sqlite3-upgrade.xml");
+        co->setDefaultValue(dataDir / SL_UPGR_FILE);
         co->makeOption(root, self);
         co = definition->findConfigSetup(ConfigVal::SERVER_STORAGE_SQLITE_DROP_FILE);
-        co->setDefaultValue(dataDir / "sqlite3-drop.sql");
+        co->setDefaultValue(dataDir / SL_DROP_FILE);
         co->makeOption(root, self);
         dbDriver = DB_DRIVER_SQLITE;
     }
@@ -378,11 +378,11 @@ void ConfigManager::load(const fs::path& userHome)
     log_info("Configuration load succeeded.");
 
     std::ostringstream buf;
-    xmlDoc->print(buf, "  ");
+    xmlDoc.print(buf, "  ");
     log_debug("Config file dump after loading: {}", buf.str());
 
     // now the XML is no longer needed we can destroy it
-    xmlDoc = nullptr;
+    xmlDoc.reset();
 }
 
 /// @brief Validate that correlated options have correct values
