@@ -3,7 +3,8 @@
     Gerbera - https://gerbera.io/
 
     config_setup.cc - this file is part of Gerbera.
-    Copyright (C) 2020-2025 Gerbera Contributors
+
+    Copyright (C) 2020-2026 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -20,7 +21,7 @@
     $Id$
 */
 
-/// \file config_setup.cc
+/// @file config/config_setup.cc
 
 #define GRB_LOG_FAC GrbLogFacility::config
 #include "config_setup.h" // API
@@ -31,6 +32,7 @@
 #include "util/logger.h"
 
 #include <numeric>
+#include <pugixml.hpp>
 
 pugi::xml_node ConfigSetup::getXmlElement(const pugi::xml_node& root) const
 {
@@ -59,8 +61,11 @@ std::string ConfigSetup::getDocs()
     return ", see documentation https://docs.gerbera.io/en/stable/config-overview.html";
 }
 
-/// \brief Returns a config option with the given xpath, if option does not exist a default value is returned.
-std::string ConfigSetup::getXmlContent(const pugi::xml_node& root, bool trim)
+/// @brief Returns a config option with the given xpath, if option does not exist a default value is returned.
+std::string ConfigSetup::getXmlContent(
+    const pugi::xml_node& root,
+    const std::shared_ptr<Config>& config,
+    bool trim)
 {
     pugi::xpath_node xpathNode = root.select_node(cpath.c_str());
 
@@ -69,6 +74,10 @@ std::string ConfigSetup::getXmlContent(const pugi::xml_node& root, bool trim)
         if (!checkValue(optValue)) {
             throw_std_runtime_error("\nInvalid {}/{} value '{}'{}", root.path(), xpath, optValue.c_str(), getDocs());
         }
+        if (config) {
+            config->registerNode(xpathNode.parent().path());
+            config->registerNode(xpathNode.node().path());
+        }
         return optValue;
     }
 
@@ -77,6 +86,11 @@ std::string ConfigSetup::getXmlContent(const pugi::xml_node& root, bool trim)
         if (!checkValue(optValue)) {
             throw_std_runtime_error("\nInvalid {}/attribute::{} value '{}'{}", root.path(), xpath, optValue.c_str(), getDocs());
         }
+        if (config) {
+            config->registerNode(root.path());
+            config->registerNode(xpathNode.parent().path());
+            config->registerNode(fmt::format("{}{}", root.path(), xpath));
+        }
         return optValue;
     }
 
@@ -87,6 +101,10 @@ std::string ConfigSetup::getXmlContent(const pugi::xml_node& root, bool trim)
         if (!checkValue(optValue)) {
             throw_std_runtime_error("\nInvalid {}/attribute::{} value '{}'{}", root.path(), xAttr, optValue, getDocs());
         }
+        if (config) {
+            config->registerNode(root.path());
+            config->registerNode(fmt::format("{}/attribute::{}", root.path(), xAttr));
+        }
         return optValue;
     }
 
@@ -95,6 +113,10 @@ std::string ConfigSetup::getXmlContent(const pugi::xml_node& root, bool trim)
         if (!checkValue(optValue)) {
             throw_std_runtime_error("\nInvalid {}/{} value '{}'{}", root.path(), xpath, optValue, getDocs());
         }
+        if (config) {
+            config->registerNode(root.child(xpath).parent().path());
+            config->registerNode(root.child(xpath).path());
+        }
         return optValue;
     }
 
