@@ -11,7 +11,7 @@
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
 
-    Copyright (C) 2016-2025 Gerbera Contributors
+    Copyright (C) 2016-2026 Gerbera Contributors
 
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -29,7 +29,7 @@
     $Id$
 */
 
-/// \file autoscan.cc
+/// @file config/result/autoscan.cc
 #define GRB_LOG_FAC GrbLogFacility::autoscan
 
 #include "autoscan.h" // API
@@ -73,7 +73,7 @@ AutoscanDirectory::AutoscanDirectory(
 
 using MediaTypeIterator = EnumIterator<AutoscanDirectory::MediaType, AutoscanDirectory::MediaType::Audio, AutoscanDirectory::MediaType::MAX>;
 
-static std::map<AutoscanDirectory::MediaType, std::string_view> mediaTypes = {
+static std::map<AutoscanDirectory::MediaType, std::string> mediaTypes = {
     { AutoscanDirectory::MediaType::Audio, "Audio" },
     { AutoscanDirectory::MediaType::Music, "Music" },
     { AutoscanDirectory::MediaType::AudioBook, "AudioBook" },
@@ -111,7 +111,7 @@ static std::map<AutoscanDirectory::MediaType, std::string> upnpClasses = {
 
 int AutoscanDirectory::makeMediaType(const std::string& optValue)
 {
-    std::vector<std::string> flagsVector = splitString(optValue, '|', false);
+    std::vector<std::string> flagsVector = splitString(optValue, '|');
     return std::accumulate(flagsVector.begin(), flagsVector.end(), 0, [](auto flg, auto&& i) { return flg | AutoscanDirectory::remapMediaType(trimString(i)); });
 }
 
@@ -123,7 +123,7 @@ std::string_view AutoscanDirectory::mapMediaType(AutoscanDirectory::MediaType mt
 std::string AutoscanDirectory::mapMediaType(int mt)
 {
     if (mt < 0)
-        return mediaTypes.at(AutoscanDirectory::MediaType::Any).data();
+        return mediaTypes.at(AutoscanDirectory::MediaType::Any);
 
     std::vector<std::string> myFlags;
 
@@ -144,12 +144,12 @@ std::string AutoscanDirectory::mapMediaType(int mt)
 int AutoscanDirectory::remapMediaType(const std::string& flag)
 {
     for (auto&& bit : MediaTypeIterator()) {
-        if (toLower(mediaTypes[bit].data()) == toLower(flag)) {
+        if (toLower(mediaTypes[bit]) == toLower(flag)) {
             return 1 << to_underlying(bit);
         }
     }
 
-    if (toLower(mediaTypes[MediaType::Any].data()) == toLower(flag)) {
+    if (toLower(mediaTypes[MediaType::Any]) == toLower(flag)) {
         return -1;
     }
     return stoiString(flag, 0, 0);
