@@ -4,7 +4,7 @@
 
     dynamic_content.h - this file is part of Gerbera.
 
-    Copyright (C) 2021-2025 Gerbera Contributors
+    Copyright (C) 2021-2026 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -21,8 +21,8 @@
     $Id$
 */
 
-/// \file dynamic_content.h
-/// \brief Definitions of the DynamicContent class.
+/// @file config/result/dynamic_content.h
+/// @brief Definitions of the DynamicContent class.
 
 #ifndef __DYNAMICCONTENT_H__
 #define __DYNAMICCONTENT_H__
@@ -30,10 +30,6 @@
 #include "edit_helper.h"
 #include "util/grb_fs.h"
 
-#include <map>
-#include <mutex>
-#include <vector>
-
 // forward declarations
 class Config;
 class DynamicContent;
@@ -44,7 +40,7 @@ public:
     std::shared_ptr<DynamicContent> getKey(const fs::path& location) const;
 };
 
-/// \brief dynamic content reader
+/// @brief dynamic content reader
 class DynamicContent : public Editable {
 public:
     DynamicContent() = default;
@@ -82,25 +78,25 @@ public:
     int getMaxCount() const { return maxCount; }
 
 private:
-    /// \brief virtual tree location
+    /// @brief virtual tree location
     fs::path location { "/Auto" };
 
-    /// \brief title
+    /// @brief title
     std::string title;
 
-    /// \brief search filter
+    /// @brief search filter
     std::string filter;
 
-    /// \brief sort criteria
+    /// @brief sort criteria
     std::string sort;
 
-    /// \brief shortcut name for upnp shortcuts list
+    /// @brief shortcut name for upnp shortcuts list
     std::string upnpShortcut;
 
-    /// \brief maximum request count
+    /// @brief maximum request count
     int maxCount {};
 
-    /// \brief folder image
+    /// @brief folder image
     fs::path image;
 };
 
