@@ -4,7 +4,7 @@
 
     config_setup_dictionary.h - this file is part of Gerbera.
 
-    Copyright (C) 2020-2025 Gerbera Contributors
+    Copyright (C) 2020-2026 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -132,7 +132,7 @@ public:
     std::shared_ptr<ConfigOption> newOption(
         const std::map<std::string, std::string>& optValue);
 
-    std::string getCurrentValue() const override { return {}; }
+    std::string getCurrentValue() const override;
 };
 
 #endif // __CONFIG_SETUP_DICTIONARY_H__
