@@ -4,7 +4,7 @@
 
     config_setup_tweak.cc - this file is part of Gerbera.
 
-    Copyright (C) 2020-2025 Gerbera Contributors
+    Copyright (C) 2020-2026 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -37,6 +37,7 @@
 #include "util/logger.h"
 
 #include <numeric>
+#include <pugixml.hpp>
 
 /// @brief Creates an array of DirectoryTweak objects from a XML nodeset.
 bool ConfigDirectorySetup::createOptionFromNode(
@@ -53,7 +54,7 @@ bool ConfigDirectorySetup::createOptionFromNode(
 
     auto&& tcs = definition->findConfigSetup<ConfigSetup>(ConfigVal::A_DIRECTORIES_TWEAK);
     for (auto&& it : tcs->getXmlTree(element)) {
-        const pugi::xml_node& child = it.node();
+        auto child = it.node();
         if (config) {
             config->registerNode(child.path());
         }
