@@ -4,7 +4,7 @@
 
     config_setup_vector.cc - this file is part of Gerbera.
 
-    Copyright (C) 2022-2025 Gerbera Contributors
+    Copyright (C) 2022-2026 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -33,6 +33,7 @@
 #include "util/logger.h"
 
 #include <numeric>
+#include <pugixml.hpp>
 
 /// @brief Creates a vector from an XML nodeset.
 bool ConfigVectorSetup::createOptionFromNode(
@@ -50,7 +51,7 @@ bool ConfigVectorSetup::createOptionFromNode(
         }
 
         for (auto&& it : dictNodes) {
-            const pugi::xml_node child = it.node();
+            auto child = it.node();
             if (config) {
                 config->registerNode(child.path());
             }
