@@ -4,7 +4,7 @@
 
     setup_util.h - this file is part of Gerbera.
 
-    Copyright (C) 2024-2025 Gerbera Contributors
+    Copyright (C) 2024-2026 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -27,8 +27,16 @@
 #ifndef __GRB_SETUP_UTIL_H_
 #define __GRB_SETUP_UTIL_H_
 
+#include "config/config_setup.h"
 #include "util/tools.h"
 
+#include <functional>
+#include <memory>
+
+class Config;
+class ConfigDefinition;
+enum class ConfigVal;
+
 /// @brief Utility struct to define properties for update
 template <class CfgResult>
 struct ConfigResultProperty {
