@@ -11,7 +11,7 @@
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
 
-    Copyright (C) 2016-2025 Gerbera Contributors
+    Copyright (C) 2016-2026 Gerbera Contributors
 
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -68,6 +68,16 @@ class Timer;
 #define DB_DRIVER_MYSQL "mysql"
 #define DB_DRIVER_POSTGRES "postgres"
 
+#define SL_DROP_FILE "sqlite3-drop.sql"
+#define SL_UPGR_FILE "sqlite3-upgrade.xml"
+#define SL_INIT_FILE "sqlite3.sql"
+#define MY_DROP_FILE "mysql-drop.sql"
+#define MY_UPGR_FILE "mysql-upgrade.xml"
+#define MY_INIT_FILE "mysql.sql"
+#define PG_DROP_FILE "postgres-drop.sql"
+#define PG_UPGR_FILE "postgres-upgrade.xml"
+#define PG_INIT_FILE "postgres.sql"
+
 enum class DbFileType {
     Auto,
     Directory,
