@@ -4,7 +4,7 @@ Gerbera - https://gerbera.io/
 
     ffmpeg_thumbnailer_handler.h - this file is part of Gerbera.
 
-    Copyright (C) 2022-2025 Gerbera Contributors
+    Copyright (C) 2022-2026 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -19,7 +19,7 @@ Gerbera - https://gerbera.io/
     along with Gerbera.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-/// \file ffmpeg_thumbnailer_handler.h
+/// @file metadata/ffmpeg_thumbnailer_handler.h
 
 #ifndef __FFMPEG_THUMBNAILER_HANDLER_H__
 #define __FFMPEG_THUMBNAILER_HANDLER_H__
@@ -36,6 +36,7 @@ class CdsObject;
 class IOHandler;
 enum class ObjectType;
 
+/// @brief class to treat virtual resource for videos and images to generate thumbnails
 class FfmpegThumbnailerHandler : public MediaMetadataHandler {
 public:
     explicit FfmpegThumbnailerHandler(
@@ -47,7 +48,9 @@ public:
         bool isOggTheora,
         const std::string& mimeType,
         ObjectType mediaType) override;
+
     bool fillMetadata(const std::shared_ptr<CdsObject>& obj) override;
+
     std::unique_ptr<IOHandler> serveContent(
         const std::shared_ptr<CdsObject>& obj,
         const std::shared_ptr<CdsResource>& resource) override;
@@ -58,13 +61,22 @@ protected:
     static fs::path getThumbnailCachePath(const fs::path& base, const fs::path& movie);
 
 private:
-    // The ffmpegthumbnailer code (ffmpeg?) is not threading safe.
-    // Add a lock around the usage to avoid crashing randomly.
+    /// @brief The ffmpegthumbnailer code (ffmpeg?) is not threading safe.
+    /// Add a lock around the usage to avoid crashing randomly.
     mutable std::mutex thumb_mutex;
+    /// @brief location of cached thumbnails
     fs::path cachePath;
+    /// @brief distinguish video or image
     ObjectType mediaType;
+
+    /// @brief read cached thumbnail
     std::optional<std::vector<std::byte>> readThumbnailCacheFile(const fs::path& movieFilename) const;
-    void writeThumbnailCacheFile(const fs::path& movieFilename, const std::byte* data, std::size_t size) const;
+
+    /// @brief cache generated thumb
+    void writeThumbnailCacheFile(
+        const fs::path& movieFilename,
+        const std::byte* data,
+        std::size_t size) const;
 };
 
 #endif // HAVE_FFMPEGTHUMBNAILER
