@@ -11,7 +11,7 @@
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
 
-    Copyright (C) 2016-2024 Gerbera Contributors
+    Copyright (C) 2016-2026 Gerbera Contributors
 
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -29,23 +29,27 @@
     $Id$
 */
 
-/// \file libexif_handler.cc
+/// @file metadata/libexif_handler.cc
 
 #ifdef HAVE_LIBEXIF
-#define LOG_FAC log_facility_t::exif
+#define GRB_LOG_FAC GrbLogFacility::exif
 #include "libexif_handler.h" // API
 
-#include <array>
-
 #include "cds/cds_item.h"
+#include "config/config_val.h"
+#include "exceptions.h"
 #include "iohandler/file_io_handler.h"
 #include "iohandler/mem_io_handler.h"
 #include "util/jpeg_resolution.h"
 #include "util/string_converter.h"
 #include "util/tools.h"
 
-/// \brief Sets resolution for a given resource index, item must be a JPEG image
-static void setJpegResolutionResource(const std::shared_ptr<CdsItem>& item, std::size_t resNum = 0)
+#include <array>
+
+/// @brief Sets resolution for a given resource index, item must be a JPEG image
+static void setJpegResolutionResource(
+    const std::shared_ptr<CdsItem>& item,
+    std::size_t resNum = 0)
 {
     if (resNum >= item->getResourceCount()) {
         log_warning("Invalid resource {} index {}", item->getLocation().c_str(), resNum);
@@ -178,107 +182,281 @@ static int getTagFromString(const std::string& tag)
     return result;
 }
 
-void LibExifHandler::process_ifd(const ExifContent* content, const std::shared_ptr<CdsItem>& item,
-    const std::unique_ptr<StringConverter>& sc, const std::vector<std::string>& auxtags, const std::map<std::string, std::string>& metatags)
+static void logfunc(ExifLog* log, ExifLogCode code, const char* domain, const char* format, va_list args, void* data)
 {
-    constexpr auto BUFLEN = 4096;
+    va_list args_copy;
+    va_copy(args_copy, args);
+    size_t len = std::vsnprintf(nullptr, 0, format, args_copy);
+    std::vector<char> buf(len + 1); // need space for NUL
+    std::vsnprintf(buf.data(), len + 1, format, args);
+    std::string message = buf.data();
+    log_debug("Exif: {}-{}, domain {}: {}", exif_log_code_get_title(code), exif_log_code_get_message(code), domain, message);
+    va_end(args_copy);
+}
+
+LibExifHandler::LibExifHandler(const std::shared_ptr<Context>& context)
+    : MediaMetadataHandler(context,
+          ConfigVal::IMPORT_LIBOPTS_EXIF_ENABLED,
+          ConfigVal::IMPORT_LIBOPTS_EXIF_METADATA_TAGS_LIST,
+          ConfigVal::IMPORT_LIBOPTS_EXIF_AUXDATA_TAGS_LIST,
+          ConfigVal::IMPORT_LIBOPTS_EXIF_COMMENT_ENABLED,
+          ConfigVal::IMPORT_LIBOPTS_EXIF_COMMENT_LIST)
+{
+    log = exif_log_new();
+    exif_log_set_func(log, logfunc, nullptr);
+}
+
+LibExifHandler::~LibExifHandler()
+{
+    exif_log_free(log);
+}
+
+/// @brief Wrapper class to interface with LibExif
+class LibExifObject {
+private:
+    static constexpr std::size_t BUFLEN = 4096;
     std::array<char, BUFLEN> exif_entry_buffer;
 #define exif_egv(arg) exif_entry_get_value(arg, exif_entry_buffer.data(), BUFLEN)
 
+public:
+    std::string location;
+    std::shared_ptr<StringConverter> sc;
+    ExifData* exifData = nullptr;
+
+    LibExifObject(const std::shared_ptr<ConverterManager>& converterManager, const std::shared_ptr<CdsItem>& item)
+        : location(item->getLocation())
+        , sc(converterManager->m2i(ConfigVal::IMPORT_LIBOPTS_EXIF_CHARSET, location))
+    {
+        exifData = exif_data_new_from_file(location.c_str());
+    }
+
+    ~LibExifObject()
+    {
+        // Close the media file
+        if (exifData)
+            exif_data_unref(exifData);
+    }
+
+    LibExifObject(const LibExifObject&) = delete;
+    LibExifObject& operator=(const LibExifObject&) = delete;
+
+    /// @brief check if libexif information is available
+    operator bool() const
+    {
+        return exifData;
+    }
+    /// @brief check if thumbnail information is available
+    bool hasThumb() const
+    {
+        return exifData && exifData->size > 0U;
+    }
+
+    /// get iohandler to serve thumbnail
+    std::unique_ptr<IOHandler> getThumbnail()
+    {
+        if (!exifData)
+            throw_std_runtime_error("Resource {} has no exif information", location);
+
+        if (!hasThumb()) {
+            throw_std_runtime_error("Resource {} has no exif thumbnail", location);
+        }
+
+        return std::make_unique<MemIOHandler>(exifData->data, exifData->size);
+    }
+
+    /// @brief get date/time
+    std::string getDate(ExifEntry* entry)
+    {
+        auto value = trimString(exif_egv(entry));
+        log_debug("Found exif date: {}", value);
+        if (!value.empty()) {
+            auto [val, err] = sc->convert(value);
+            if (!err.empty()) {
+                log_warning("{}: {}", location, err);
+            }
+            // convert date to ISO 8601 as required in the UPnP spec
+            // from YYYY:MM:DD to YYYY-MM-DD
+            if (val.length() >= 19) {
+                return val;
+            } else if (val.length() >= 11) {
+                return val;
+            }
+            return "";
+        }
+        return "";
+    }
+
+    /// @brief get key value from image
+    std::string getKey(ExifEntry* entry)
+    {
+        auto value = trimString(exif_egv(entry));
+        log_debug("Found exif value: {}", value);
+        if (!value.empty()) {
+            auto [val, err] = sc->convert(value);
+            if (!err.empty()) {
+                log_warning("{}: {}", location, err);
+            }
+            return val;
+        }
+        return "";
+    }
+
+    /// @brief get resolution for thumbnail
+    std::string getThumbResolution()
+    {
+        try {
+            auto ioH = MemIOHandler(exifData->data, exifData->size);
+            ioH.open(UPNP_READ);
+            auto thResolution = getJpegResolution(ioH);
+            log_debug("EXIF Thumb Resolution: {}", thResolution.string());
+            return thResolution.string();
+        } catch (const std::runtime_error& e) {
+            log_error("Failed to parse EXIF Thumbnail {} details: {}", location, e.what());
+        }
+        return "";
+    }
+};
+
+bool LibExifHandler::isSupported(
+    const std::string& contentType,
+    bool isOggTheora,
+    const std::string& mimeType,
+    ObjectType mediaType)
+{
+    return contentType == CONTENT_TYPE_JPG;
+}
+
+void LibExifHandler::process_ifd(
+    const ExifContent* content,
+    const std::shared_ptr<CdsItem>& item,
+    LibExifObject& exifObject,
+    std::vector<std::string>& snippets,
+    std::string& imageX,
+    std::string& imageY)
+{
     for (std::size_t i = 0; i < content->count; i++) {
         ExifEntry* entry = content->entries[i];
 
         switch (entry->tag) {
         case EXIF_TAG_DATE_TIME_ORIGINAL: {
-            auto value = trimString(exif_egv(entry));
-            log_debug("Found exif date: {}", value);
-            if (!value.empty()) {
-                value = sc->convert(value);
+            auto val = exifObject.getDate(entry);
+            log_debug("Found exif date: {}", val);
+            if (!val.empty()) {
                 // convert date to ISO 8601 as required in the UPnP spec
                 // from YYYY:MM:DD to YYYY-MM-DD
-                if (value.length() >= 19) {
-                    item->addMetaData(MetadataFields::M_DATE, fmt::format("{}-{}-{}T{}", value.substr(0, 4), value.substr(5, 2), value.substr(8, 2), value.substr(11, 8)));
-                } else if (value.length() >= 11) {
-                    item->addMetaData(MetadataFields::M_DATE, fmt::format("{}-{}-{}", value.substr(0, 4), value.substr(5, 2), value.substr(8, 2)));
+                if (val.length() >= 19) {
+                    val = fmt::format("{}-{}-{}T{}", val.substr(0, 4), val.substr(5, 2), val.substr(8, 2), val.substr(11, 8));
+                } else { // otherwise getDate returned empty string
+                    val = fmt::format("{}-{}-{}", val.substr(0, 4), val.substr(5, 2), val.substr(8, 2));
                 }
+                item->addMetaData(MetadataFields::M_DATE, val);
             }
             break;
         }
         case EXIF_TAG_USER_COMMENT: {
-            auto value = trimString(exif_egv(entry));
+            auto value = exifObject.getKey(entry);
             log_debug("Found exif comment: {}", value);
             if (!value.empty()) {
-                item->addMetaData(MetadataFields::M_DESCRIPTION, sc->convert(value));
+                item->addMetaData(MetadataFields::M_DESCRIPTION, value);
             }
             break;
         }
         case EXIF_TAG_PIXEL_X_DIMENSION: {
-            auto value = trimString(exif_egv(entry));
+            auto value = exifObject.getKey(entry);
             log_debug("Found exif X dimension: {}", value);
             if (!value.empty()) {
-                imageX = sc->convert(value);
+                imageX = value;
             }
             break;
         }
         case EXIF_TAG_PIXEL_Y_DIMENSION: {
-            auto value = trimString(exif_egv(entry));
+            auto value = exifObject.getKey(entry);
             log_debug("Found exif Y dimension: {}", value);
             if (!value.empty()) {
-                imageY = sc->convert(value);
+                imageY = value;
             }
             break;
         }
+        case EXIF_TAG_ORIENTATION: {
+            auto o = exif_data_get_byte_order(entry->parent->parent);
+            auto value = exif_get_short(entry->data, o);
+            log_debug("Found exif orientation {}", value);
+            item->getResource(ContentHandler::DEFAULT)->addAttribute(ResourceAttribute::ORIENTATION, fmt::format("{}", value));
+            break;
+        }
         default:
             break;
         }
 
         // if there are any metadata tags that the user wants - add them
-        for (auto&& [tag, key] : metatags) {
+        for (auto&& [tag, key] : metaTags) {
             if (tag.empty() || entry->tag != getTagFromString(tag))
                 continue;
 
-            auto value = trimString(exif_egv(entry));
+            auto value = exifObject.getKey(entry);
             if (!value.empty()) {
-                item->addMetaData(key, sc->convert(value));
+                item->addMetaData(key, value);
                 log_debug("Adding tag '{}' as '{}' with value '{}'", tag, key, value);
             }
         }
         // if there are any auxilary tags that the user wants - add them
-        for (auto&& aux : auxtags) {
+        for (auto&& aux : auxTags) {
             if (aux.empty() || entry->tag != getTagFromString(aux))
                 continue;
 
-            auto value = trimString(exif_egv(entry));
+            auto value = exifObject.getKey(entry);
             if (!value.empty()) {
-                item->setAuxData(aux, sc->convert(value));
+                item->setAuxData(aux, value);
                 log_debug("Adding aux: {} with value {}", aux, value);
             }
         }
+        // if user want a fabricated comment
+        for (auto&& [label, tag] : commentMap) {
+            if (tag.empty() || entry->tag != getTagFromString(tag))
+                continue;
+
+            auto value = exifObject.getKey(entry);
+            if (!value.empty()) {
+                log_debug("Added comment {}: {}", label, value);
+                snippets.push_back(fmt::format("{}: {}", label, value));
+            }
+        }
     }
 }
 
-void LibExifHandler::fillMetadata(const std::shared_ptr<CdsObject>& obj)
+bool LibExifHandler::fillMetadata(const std::shared_ptr<CdsObject>& obj)
 {
     auto item = std::dynamic_pointer_cast<CdsItem>(obj);
-    if (!item)
-        return;
+    if (!item || !isEnabled)
+        return false;
 
-    auto sc = StringConverter::m2i(CFG_IMPORT_LIBOPTS_EXIF_CHARSET, item->getLocation(), config);
-    ExifData* exifData = exif_data_new_from_file(item->getLocation().c_str());
+    LibExifObject exifObject(converterManager, item);
 
-    if (exifData == nullptr) {
+    if (!exifObject) {
         log_debug("Exif data not found, attempting to set resolution internally...");
         setJpegResolutionResource(item);
-        return;
+        return true;
     }
 
-    auto aux = config->getArrayOption(CFG_IMPORT_LIBOPTS_EXIF_AUXDATA_TAGS_LIST);
-    auto meta = config->getDictionaryOption(CFG_IMPORT_LIBOPTS_EXIF_METADATA_TAGS_LIST);
-    for (auto* exifContent : exifData->ifd) {
+    // image resolution in pixels
+    // the problem is that I do not know when I encounter the
+    // tags for X and Y, so I have to save the information
+    // and in the very end - when I have both values - add the
+    // appropriate resource
+    std::string imageX;
+    std::string imageY;
+
+    std::vector<std::string> snippets;
+    for (auto* exifContent : exifObject.exifData->ifd) {
         if (exifContent != nullptr) {
-            process_ifd(exifContent, item, sc, aux, meta);
+            process_ifd(exifContent, item, exifObject, snippets, imageX, imageY);
         }
     }
+    if (!snippets.empty() && item->getMetaData(MetadataFields::M_DESCRIPTION).empty() && isCommentEnabled) {
+        auto comment = fmt::format("{}", fmt::join(snippets, ", "));
+        log_debug("Fabricated Comment: {}", comment);
+        item->addMetaData(MetadataFields::M_DESCRIPTION, comment);
+    }
 
     // we got the image resolution so we can add our resource
     if (!imageX.empty() && !imageY.empty()) {
@@ -288,24 +466,20 @@ void LibExifHandler::fillMetadata(const std::shared_ptr<CdsObject>& obj)
         setJpegResolutionResource(item);
     }
 
-    if (exifData->size != 0U) {
+    if (exifObject.hasThumb()) {
         auto resource = std::make_shared<CdsResource>(ContentHandler::LIBEXIF, ResourcePurpose::Thumbnail);
         resource->addAttribute(ResourceAttribute::PROTOCOLINFO, renderProtocolInfo(item->getMimeType()));
         item->addResource(resource);
-        try {
-            auto ioH = MemIOHandler(exifData->data, exifData->size);
-            ioH.open(UPNP_READ);
-            auto thResolution = getJpegResolution(ioH);
-            log_debug("EXIF Thumb Resolution: {}", thResolution.string());
-            resource->addAttribute(ResourceAttribute::RESOLUTION, thResolution.string());
-        } catch (const std::runtime_error& e) {
-            log_error("Failed to parse EXIF Thumbnail {} details: {}", item->getLocation().c_str(), e.what());
-        }
-    } // (exifData->size)
-    exif_data_unref(exifData);
+        auto resolution = exifObject.getThumbResolution();
+        if (!resolution.empty())
+            resource->addAttribute(ResourceAttribute::RESOLUTION, resolution);
+    }
+    return true;
 }
 
-std::unique_ptr<IOHandler> LibExifHandler::serveContent(const std::shared_ptr<CdsObject>& obj, const std::shared_ptr<CdsResource>& resource)
+std::unique_ptr<IOHandler> LibExifHandler::serveContent(
+    const std::shared_ptr<CdsObject>& obj,
+    const std::shared_ptr<CdsResource>& resource)
 {
     auto item = std::dynamic_pointer_cast<CdsItem>(obj);
     if (!item)
@@ -314,15 +488,8 @@ std::unique_ptr<IOHandler> LibExifHandler::serveContent(const std::shared_ptr<Cd
     if (resource->getPurpose() != ResourcePurpose::Thumbnail)
         throw_std_runtime_error("Resource {} is not a Thumbnail", resource->getPurpose());
 
-    ExifData* ed = exif_data_new_from_file(item->getLocation().c_str());
-    if (!ed)
-        throw_std_runtime_error("Resource {} has no exif information", item->getLocation().string());
+    LibExifObject exifObject(converterManager, item);
 
-    if (!(ed->size))
-        throw_std_runtime_error("Resource {} has no exif thumbnail", item->getLocation().string());
-
-    auto ioHandler = std::make_unique<MemIOHandler>(ed->data, ed->size);
-    exif_data_unref(ed);
-    return ioHandler;
+    return exifObject.getThumbnail();
 }
 #endif // HAVE_LIBEXIF
