@@ -11,7 +11,7 @@
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
 
-    Copyright (C) 2016-2025 Gerbera Contributors
+    Copyright (C) 2016-2026 Gerbera Contributors
 
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -29,7 +29,7 @@
     $Id$
 */
 
-/// \file taglib_handler.cc
+/// @file metadata/taglib_handler.cc
 
 #ifdef HAVE_TAGLIB
 #define GRB_LOG_FAC GrbLogFacility::taglib
@@ -52,6 +52,7 @@
 #include <asffile.h>
 #include <attachedpictureframe.h>
 #include <flacfile.h>
+#include <fmt/chrono.h>
 #include <id3v2tag.h>
 #include <mp4file.h>
 #include <mpegfile.h>
@@ -148,7 +149,15 @@ void TagLibHandler::addField(
         unsigned int i = tag->year();
         if (i == 0)
             return;
-        value.push_back(fmt::format("{}-01-01", i));
+        if (i < 10000) {
+            value.push_back(fmt::format("{}-01-01", i));
+        } else {
+            auto val = fmt::format("{}", i);
+            std::tm tmWork {};
+            if (parseDate(val.c_str(), tmWork)) {
+                value.push_back(fmt::format("{:%Y-%m-%d}", tmWork));
+            }
+        }
         break;
     }
     case MetadataFields::M_DESCRIPTION:
@@ -352,8 +361,8 @@ void TagLibHandler::makeComment(
     log_debug("Fabricated Comment: {}", fmt::format("{}", fmt::join(snippets, ", ")));
 }
 
-/// \brief read metadata from file and add to object
-/// \param obj Object to handle
+/// @brief read metadata from file and add to object
+/// @param obj Object to handle
 bool TagLibHandler::fillMetadata(const std::shared_ptr<CdsObject>& obj)
 {
     auto item = std::dynamic_pointer_cast<CdsItem>(obj);
@@ -405,10 +414,10 @@ std::string TagLibHandler::getContentTypeFromByteVector(const TagLib::ByteVector
 #endif
 }
 
-/// \brief stream content of object or resource to client
-/// \param obj Object to stream
-/// \param resource the resource
-/// \return iohandler to stream to client
+/// @brief stream content of object or resource to client
+/// @param obj Object to stream
+/// @param resource the resource
+/// @return iohandler to stream to client
 std::unique_ptr<IOHandler> TagLibHandler::serveContent(
     const std::shared_ptr<CdsObject>& obj,
     const std::shared_ptr<CdsResource>& resource)
