@@ -11,7 +11,7 @@
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
 
-    Copyright (C) 2016-2025 Gerbera Contributors
+    Copyright (C) 2016-2026 Gerbera Contributors
 
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -29,7 +29,7 @@
     $Id$
 */
 
-/// \file cont_dir_service.cc
+/// @file upnp/cont_dir_service.cc
 #define GRB_LOG_FAC GrbLogFacility::cds
 
 #include "cont_dir_service.h" // API
@@ -123,6 +123,8 @@ void ContentDirectoryService::doBrowse(ActionRequest& request)
     auto upnpClass = parent->getClass();
     if (sortCriteria.empty() && (startswith(upnpClass, UPNP_CLASS_MUSIC_ALBUM) || startswith(upnpClass, UPNP_CLASS_PLAYLIST_CONTAINER)))
         flag |= BROWSE_TRACK_SORT;
+    else if (quirks->hasFlag(Quirk::ForceSortCriteriaTitle))
+        sortCriteria = fmt::format("+{}", MetaEnumMapper::getMetaFieldName(MetadataFields::M_TITLE));
     if (filter.empty())
         filter = "*";
     if (config->getBoolOption(ConfigVal::SERVER_HIDE_PC_DIRECTORY))
@@ -130,7 +132,7 @@ void ContentDirectoryService::doBrowse(ActionRequest& request)
 
     auto param = BrowseParam(parent, flag);
 
-    param.setDynamicContainers(!quirks || !quirks->checkFlags(QUIRK_FLAG_SAMSUNG_HIDE_DYNAMIC));
+    param.setDynamicContainers(!quirks || !quirks->hasFlag(Quirk::SamsungHideDynamic));
     param.setStartingIndex(startingIndex);
     param.setRequestedCount(requestedCount);
     param.setSortCriteria(trimString(sortCriteria));
@@ -157,7 +159,7 @@ void ContentDirectoryService::doBrowse(ActionRequest& request)
 
     // build response
     pugi::xml_document didlLite;
-    if (!quirks->blockXmlDeclaration()) {
+    if (!quirks->hasFlag(Quirk::NoXmlDeclaration)) {
         auto decl = didlLite.prepend_child(pugi::node_declaration);
         decl.append_attribute("version") = "1.0";
         decl.append_attribute("encoding") = "UTF-8";
@@ -178,7 +180,7 @@ void ContentDirectoryService::doBrowse(ActionRequest& request)
         xmlBuilder->renderObject(obj, splitString(filter, ','), stringLimitClient, didlLiteRoot, quirks);
     }
 
-    std::string didlLiteXml = UpnpXMLBuilder::printXml(didlLite, "", quirks && quirks->needsStrictXml() ? pugi::format_no_escapes : 0);
+    std::string didlLiteXml = UpnpXMLBuilder::printXml(didlLite, "", quirks && quirks->hasFlag(Quirk::StrictXML) ? pugi::format_no_escapes : 0);
     log_debug("didl {}", didlLiteXml);
 
     auto response = xmlBuilder->createResponse(request.getActionName(), UPNP_DESC_CDS_SERVICE_TYPE);
@@ -219,7 +221,7 @@ void ContentDirectoryService::doSearch(ActionRequest& request)
 
     auto&& quirks = request.getQuirks();
     pugi::xml_document didlLite;
-    if (!quirks || !quirks->blockXmlDeclaration()) {
+    if (!quirks || !quirks->hasFlag(Quirk::NoXmlDeclaration)) {
         auto decl = didlLite.prepend_child(pugi::node_declaration);
         decl.append_attribute("version") = "1.0";
         decl.append_attribute("encoding") = "UTF-8";
@@ -229,9 +231,9 @@ void ContentDirectoryService::doSearch(ActionRequest& request)
     didlLiteRoot.append_attribute(UPNP_XML_DC_NAMESPACE_ATTR) = UPNP_XML_DC_NAMESPACE;
     didlLiteRoot.append_attribute(UPNP_XML_UPNP_NAMESPACE_ATTR) = UPNP_XML_UPNP_NAMESPACE;
     didlLiteRoot.append_attribute(UPNP_XML_SEC_NAMESPACE_ATTR) = UPNP_XML_SEC_NAMESPACE;
-    if (quirks->checkFlags(QUIRK_FLAG_PV_SUBTITLES))
+    if (quirks->hasFlag(Quirk::PvSubtitles))
         didlLiteRoot.append_attribute("xmlns:pv") = "http://www.pv.com/pvns/";
-    if (sortCriteria.empty()) {
+    if (sortCriteria.empty() || quirks->hasFlag(Quirk::ForceSortCriteriaTitle)) {
         sortCriteria = fmt::format("+{}", MetaEnumMapper::getMetaFieldName(MetadataFields::M_TITLE));
     }
     if (filter.empty())
@@ -286,7 +288,7 @@ void ContentDirectoryService::doSearch(ActionRequest& request)
         xmlBuilder->renderObject(cdsObject, splitString(filter, ','), stringLimitClient, didlLiteRoot);
     }
 
-    std::string didlLiteXml = UpnpXMLBuilder::printXml(didlLite, "", quirks && quirks->needsStrictXml() ? pugi::format_no_escapes : 0);
+    std::string didlLiteXml = UpnpXMLBuilder::printXml(didlLite, "", quirks && quirks->hasFlag(Quirk::StrictXML) ? pugi::format_no_escapes : 0);
     log_debug("didl {}", didlLiteXml);
 
     auto response = xmlBuilder->createResponse(request.getActionName(), UPNP_DESC_CDS_SERVICE_TYPE);
@@ -433,7 +435,7 @@ void ContentDirectoryService::doSamsungGetIndexfromRID(ActionRequest& request)
     log_debug("end");
 }
 
-bool ContentDirectoryService::processSubscriptionRequest(const SubscriptionRequest& request)
+bool ContentDirectoryService::processSubscriptionRequest(const SubscriptionRequest& request) const
 {
     log_debug("start");
 
