@@ -29,7 +29,7 @@
     $Id$
 */
 
-/// \file upnp/xml_builder.cc
+/// @file upnp/xml_builder.cc
 #define GRB_LOG_FAC GrbLogFacility::xml
 
 #include "xml_builder.h" // API
@@ -379,8 +379,8 @@ void UpnpXMLBuilder::renderObject(
     result.append_attribute("restricted") = obj->isRestricted() ? "1" : "0";
 
     UpnpXMLBuilder::XmlStringFormat xmlFormat = {
-        quirks && quirks->needsStrictXml(),
-        quirks && quirks->needsAsciiXml(),
+        quirks && quirks->hasFlag(Quirk::StrictXML),
+        quirks && quirks->hasFlag(Quirk::AsciiXML),
         stringLimit,
     };
     const std::string title = obj->getTitle();
@@ -400,7 +400,7 @@ void UpnpXMLBuilder::renderObject(
         if (quirks) {
             quirks->restoreSamsungBookMarkedPosition(item, result, config->getLongOption(ConfigVal::CLIENTS_BOOKMARK_OFFSET));
             mvMeta = quirks->getMultiValue();
-            simpleDate = quirks->needsSimpleDate();
+            simpleDate = quirks->hasFlag(Quirk::SimpleDate);
         }
 
         auto metaGroups = obj->getMetaGroups();
@@ -518,7 +518,7 @@ std::unique_ptr<pugi::xml_document> UpnpXMLBuilder::createEventPropertySet() con
     return doc;
 }
 
-/// \brief: gerbera uses these resource attributes for internal mechanisms
+/// @brief gerbera uses these resource attributes for internal mechanisms
 static bool isPrivateAttribute(ResourceAttribute attribute)
 {
     switch (attribute) {
@@ -535,7 +535,8 @@ static bool isPrivateAttribute(ResourceAttribute attribute)
     }
 }
 
-void UpnpXMLBuilder::renderResource(const CdsObject& object,
+void UpnpXMLBuilder::renderResource(
+    const CdsObject& object,
     const CdsResource& resource,
     pugi::xml_node& parent,
     const std::vector<std::string>& filter,
@@ -575,6 +576,24 @@ void UpnpXMLBuilder::renderResource(const CdsObject& object,
     }
 }
 
+class UrlBuilder {
+private:
+    std::string handler;
+
+public:
+    UrlBuilder(std::string hdlr)
+        : handler(std::move(hdlr))
+    {
+    }
+    std::string buildUrl(const std::string& root, int id, int resId = -1) const
+    {
+        return root + URLUtils::joinUrl({ handler, URL_OBJECT_ID, fmt::to_string(id), URL_RESOURCE_ID, resId >= 0 ? fmt::to_string(resId) : URL_VALUE_TRANSCODE_NO_RES_ID });
+    }
+};
+
+static auto mediaContentBuilder = UrlBuilder(CONTENT_MEDIA_HANDLER);
+static auto onlineContentBuilder = UrlBuilder(CONTENT_ONLINE_HANDLER);
+
 std::string UpnpXMLBuilder::renderResourceURL(
     const CdsObject& item,
     const CdsResource& res,
@@ -587,7 +606,7 @@ std::string UpnpXMLBuilder::renderResourceURL(
     if (item.isContainer()) {
         auto resFile = res.getAttribute(ResourceAttribute::RESOURCE_FILE);
         if (!resFile.empty()) {
-            url = virtualURL + URLUtils::joinUrl({ CONTENT_MEDIA_HANDLER, URL_OBJECT_ID, fmt::to_string(item.getID()), URL_RESOURCE_ID, fmt::to_string(res.getResId()) });
+            url = mediaContentBuilder.buildUrl(virtualURL, item.getID(), res.getResId());
         }
 
         auto resObjID = res.getAttribute(ResourceAttribute::FANART_OBJ_ID);
@@ -601,6 +620,7 @@ std::string UpnpXMLBuilder::renderResourceURL(
                     auto subObjID = stoiString(resRes->getAttribute(ResourceAttribute::FANART_OBJ_ID));
                     if (subObjID > CDS_ID_ROOT && subObjID != resObj->getID() && resRes->getAttribute(ResourceAttribute::RESOURCE_FILE).empty()) {
                         resObj = database->loadObject(subObjID);
+                        log_debug("FANART_OBJ_ID {} -> {}", objID, subObjID);
                         objID = subObjID;
                         resID = stoiString(resRes->getAttribute(ResourceAttribute::FANART_RES_ID));
                     } else {
@@ -612,7 +632,7 @@ std::string UpnpXMLBuilder::renderResourceURL(
             }
             if (objID <= CDS_ID_ROOT)
                 objID = item.getID();
-            url = virtualURL + URLUtils::joinUrl({ CONTENT_MEDIA_HANDLER, URL_OBJECT_ID, fmt::to_string(objID), URL_RESOURCE_ID, fmt::to_string(resID) });
+            url = mediaContentBuilder.buildUrl(virtualURL, objID, resID);
         }
     } else if (item.isExternalItem()) {
         if (purpose == ResourcePurpose::Content) {
@@ -623,12 +643,12 @@ std::string UpnpXMLBuilder::renderResourceURL(
             }
 
             // Proxied remote URL
-            if (item.getFlag(OBJECT_FLAG_ONLINE_SERVICE) && item.getFlag(OBJECT_FLAG_PROXY_URL)) {
-                url = virtualURL + URLUtils::joinUrl({ CONTENT_ONLINE_HANDLER, URL_OBJECT_ID, fmt::to_string(item.getID()), URL_RESOURCE_ID, fmt::to_string(res.getResId()) });
+            if (item.getFlag(OBJECT_FLAG_PROXY_URL)) {
+                url = onlineContentBuilder.buildUrl(virtualURL, item.getID(), res.getResId());
             }
         } else if (purpose == ResourcePurpose::Transcode) {
             // Transcoded resources dont set a resId, uses pr_name from params instead.
-            url = virtualURL + URLUtils::joinUrl({ CONTENT_ONLINE_HANDLER, URL_OBJECT_ID, fmt::to_string(item.getID()), URL_RESOURCE_ID, URL_VALUE_TRANSCODE_NO_RES_ID });
+            url = onlineContentBuilder.buildUrl(virtualURL, item.getID());
         } else if (purpose == ResourcePurpose::Thumbnail && res.getHandlerType() == ContentHandler::EXTURL && !item.getFlag(OBJECT_FLAG_PROXY_URL)) {
             url = res.getAttribute(ResourceAttribute::RESOURCE_FILE);
             if (url.empty())
@@ -645,9 +665,9 @@ std::string UpnpXMLBuilder::renderResourceURL(
     if (url.empty()) {
         if (purpose == ResourcePurpose::Transcode) {
             // Transcoded resources dont set a resId, uses pr_name from params instead.
-            url = virtualURL + URLUtils::joinUrl({ CONTENT_MEDIA_HANDLER, URL_OBJECT_ID, fmt::to_string(item.getID()), URL_RESOURCE_ID, URL_VALUE_TRANSCODE_NO_RES_ID });
+            url = mediaContentBuilder.buildUrl(virtualURL, item.getID());
         } else {
-            url = virtualURL + URLUtils::joinUrl({ CONTENT_MEDIA_HANDLER, URL_OBJECT_ID, fmt::to_string(item.getID()), URL_RESOURCE_ID, fmt::to_string(res.getResId()) });
+            url = mediaContentBuilder.buildUrl(virtualURL, item.getID(), res.getResId());
         }
     }
 
@@ -679,9 +699,10 @@ std::string UpnpXMLBuilder::renderResourceURL(
     return url;
 }
 
-/// \brief build path for first resource from item
+/// @brief build path for first resource from item
 /// depending on the item type it returns the url to the media
-std::string UpnpXMLBuilder::getFirstResourcePath(const std::shared_ptr<CdsItem>& item) const
+std::string UpnpXMLBuilder::getFirstResourcePath(
+    const std::shared_ptr<CdsItem>& item) const
 {
     auto res = item->getResource(ResourcePurpose::Content);
     if (res)
@@ -689,7 +710,8 @@ std::string UpnpXMLBuilder::getFirstResourcePath(const std::shared_ptr<CdsItem>&
     return {};
 }
 
-std::optional<std::string> UpnpXMLBuilder::renderContainerImageURL(const std::shared_ptr<CdsContainer>& cont) const
+std::optional<std::string> UpnpXMLBuilder::renderContainerImageURL(
+    const std::shared_ptr<CdsContainer>& cont) const
 {
     auto orderedResources = getOrderedResources(*cont);
     auto resFound = std::find_if(orderedResources.begin(), orderedResources.end(), [](auto&& res) { return res->getPurpose() == ResourcePurpose::Thumbnail; });
@@ -699,7 +721,16 @@ std::optional<std::string> UpnpXMLBuilder::renderContainerImageURL(const std::sh
     return {};
 }
 
-std::optional<std::string> UpnpXMLBuilder::renderItemImageURL(const std::shared_ptr<CdsItem>& item) const
+std::optional<std::string> UpnpXMLBuilder::renderContainerZipURL(
+    const std::shared_ptr<CdsContainer>& cont) const
+{
+    auto url = mediaContentBuilder.buildUrl(virtualURL, cont->getID());
+    url.append(URLUtils::joinUrl({ URL_PARAM_ZIP_REQUEST, fmt::format("{}.zip", cont->getTitle()) }));
+    return url;
+}
+
+std::optional<std::string> UpnpXMLBuilder::renderItemImageURL(
+    const std::shared_ptr<CdsItem>& item) const
 {
     auto orderedResources = getOrderedResources(*item);
     auto resFound = std::find_if(orderedResources.begin(), orderedResources.end(), [](auto&& res) { return res->getPurpose() == ResourcePurpose::Thumbnail; });
@@ -907,12 +938,19 @@ std::pair<bool, int> UpnpXMLBuilder::insertTempTranscodingResource(
                     continue;
                 }
             }
+
             // check for client profile prop and filter if no match
             if (!filter->getSourceProfile().empty() && filter->getSourceProfile() != sourceProfile) {
                 continue;
             }
+
+            // check for no client flags and filter if no match
+            if (quirks && filter->getClientFlags() == QUIRK_FLAG_NONE && filter->matchesWithOut() && !quirks->hasFlag(~QUIRK_FLAG_NONE, true)) {
+                continue;
+            }
+
             // check for client flags and filter if no match
-            if (quirks && filter->getClientFlags() > 0 && quirks->checkFlags(filter->getClientFlags()) == 0) {
+            if (quirks && filter->getClientFlags() != QUIRK_FLAG_NONE && !quirks->hasFlag(filter->getClientFlags(), filter->matchesWithOut())) {
                 continue;
             }
 
@@ -925,10 +963,16 @@ std::pair<bool, int> UpnpXMLBuilder::insertTempTranscodingResource(
             if (!tp->isEnabled())
                 continue;
 
-            // check for client profile prop and filter if no match
-            if (quirks && tp->getClientFlags() > 0 && quirks->checkFlags(tp->getClientFlags()) == 0) {
+            // check for no client flags and filter if no match
+            if (quirks && tp->getClientFlags() == QUIRK_FLAG_NONE && tp->matchesWithOut() && !quirks->hasFlag(~QUIRK_FLAG_NONE, true)) {
                 continue;
             }
+
+            // check for client profile prop and filter if no match
+            if (quirks && tp->getClientFlags() != QUIRK_FLAG_NONE && !quirks->hasFlag(tp->getClientFlags(), tp->matchesWithOut())) {
+                continue;
+            }
+
             if (ct == CONTENT_TYPE_OGG) {
                 if ((item->getFlag(OBJECT_FLAG_OGG_THEORA) && !tp->isTheora()) || (!item->getFlag(OBJECT_FLAG_OGG_THEORA) && tp->isTheora())) {
                     continue;
@@ -1069,7 +1113,7 @@ void UpnpXMLBuilder::addResources(
         }
 
         if (purpose == ResourcePurpose::Subtitle) {
-            if (quirks && res->getHandlerType() != ContentHandler::SUBTITLE && !quirks->showInternalSubtitles()) {
+            if (quirks && res->getHandlerType() != ContentHandler::SUBTITLE && !quirks->hasFlag(Quirk::ShowInternalSubtitles)) {
                 continue;
             }
             auto captionInfo = std::map<std::string, std::string>();
@@ -1082,7 +1126,8 @@ void UpnpXMLBuilder::addResources(
             for (auto&& [from, to] : mimeMappings) {
                 replaceAllString(protocolInfo, from, to);
             }
-            captionInfo[EnumMapper::getAttributeName(ResourceAttribute::PROTOCOLINFO)] = protocolInfo;
+            if (quirks && quirks->hasFlag(Quirk::CaptionProtocol))
+                captionInfo[EnumMapper::getAttributeName(ResourceAttribute::PROTOCOLINFO)] = protocolInfo;
 
             captionInfoEx.push_back(std::move(captionInfo));
             continue;
@@ -1116,12 +1161,12 @@ void UpnpXMLBuilder::addResources(
             if (!quirks->supportsResource(purpose)) {
                 continue;
             }
-            if (purpose == ResourcePurpose::Subtitle && res->getHandlerType() != ContentHandler::SUBTITLE && !quirks->showInternalSubtitles()) {
+            if (purpose == ResourcePurpose::Subtitle && res->getHandlerType() != ContentHandler::SUBTITLE && !quirks->hasFlag(Quirk::ShowInternalSubtitles)) {
                 continue;
             }
         }
         std::map<std::string, std::string> clientSpecficAttrs;
-        if (res->getHandlerType() == ContentHandler::DEFAULT && !captionInfoEx.empty() && quirks && quirks->checkFlags(QUIRK_FLAG_PV_SUBTITLES)) {
+        if (res->getHandlerType() == ContentHandler::DEFAULT && !captionInfoEx.empty() && quirks && quirks->hasFlag(Quirk::PvSubtitles)) {
             auto captionInfo = captionInfoEx[0];
             clientSpecficAttrs["pv:subtitleFileType"] = toUpper(captionInfo["sec:type"]);
             clientSpecficAttrs["pv:subtitleFileUri"] = captionInfo[""];
@@ -1185,7 +1230,7 @@ std::string UpnpXMLBuilder::buildProtocolInfo(
     // we do not support seeking at all, so 00
     // and the media is converted, so set CI to 1
     if (resource.getPurpose() == ResourcePurpose::Transcode) {
-        extend.append(fmt::format("{}={};{}={}", UPNP_DLNA_OP, UPNP_DLNA_OP_SEEK_DISABLED, UPNP_DLNA_CONVERSION_INDICATOR, quirks && quirks->needsNoConversion() ? UPNP_DLNA_NO_CONVERSION : UPNP_DLNA_CONVERSION));
+        extend.append(fmt::format("{}={};{}={}", UPNP_DLNA_OP, UPNP_DLNA_OP_SEEK_DISABLED, UPNP_DLNA_CONVERSION_INDICATOR, quirks && quirks->hasFlag(Quirk::ForceNoConversion) ? UPNP_DLNA_NO_CONVERSION : UPNP_DLNA_CONVERSION));
     } else {
         extend.append(fmt::format("{}={};{}={}", UPNP_DLNA_OP, UPNP_DLNA_OP_SEEK_RANGE, UPNP_DLNA_CONVERSION_INDICATOR, UPNP_DLNA_NO_CONVERSION));
     }
