@@ -11,7 +11,7 @@
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
 
-    Copyright (C) 2016-2024 Gerbera Contributors
+    Copyright (C) 2016-2026 Gerbera Contributors
 
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -29,11 +29,13 @@
     $Id$
 */
 
-/// \file generic_task.cc
+/// @file util/generic_task.cc
 
 #include "generic_task.h" // API
 
-GenericTask::GenericTask(task_owner_t taskOwner)
+GenericTask::GenericTask(TaskOwner taskOwner)
     : taskOwner(taskOwner)
 {
 }
+
+GenericTask::~GenericTask() = default;
