@@ -11,7 +11,7 @@
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
 
-    Copyright (C) 2016-2025 Gerbera Contributors
+    Copyright (C) 2016-2026 Gerbera Contributors
 
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -34,9 +34,8 @@
 #define __TOOLS_H__
 
 #include <algorithm>
-#include <cinttypes>
+#include <cstdint>
 #include <map>
-#include <optional>
 #include <string>
 #include <vector>
 
@@ -44,7 +43,7 @@
 class IOHandler;
 
 // default protocol
-constexpr auto PROTOCOL = std::string_view("http-get");
+constexpr auto PROTOCOL = "http-get";
 
 /// @brief splits the given string into array of strings using a separator character.
 /// @param str String to split
@@ -52,7 +51,11 @@ constexpr auto PROTOCOL = std::string_view("http-get");
 /// @param quote masking character encapsulating separators
 /// @param empty treat subsequent separators as empty array elements
 /// @return array of strings
-std::vector<std::string> splitString(std::string_view str, char sep, char quote = '\0', bool empty = false);
+std::vector<std::string> splitString(
+    std::string str,
+    char sep,
+    char quote = '\0',
+    bool empty = false);
 
 /// @brief remove leading and trailing whitespace (in place)
 void trimStringInPlace(std::string& str);
@@ -149,18 +152,21 @@ std::string mimeTypesToCsv(const std::vector<std::string>& mimeTypes);
 /// @param protocol the protocol which should be inserted (default: "http-get")
 /// @param extend extend the protocolInfo
 /// @return The rendered protocolInfo String
-std::string renderProtocolInfo(std::string_view mimetype, std::string_view protocol = PROTOCOL, std::string_view extend = "");
+std::string renderProtocolInfo(
+    const std::string& mimetype,
+    const std::string& protocol = PROTOCOL,
+    const std::string& extend = "");
 
 /// @brief Extracts mimetype from the protocol info string.
 /// @param protocol info string as used in the protocolInfo attribute
 /// @return mime-type in protocol
-std::string getMTFromProtocolInfo(std::string_view protocol);
+std::string getMTFromProtocolInfo(const std::string& protocol);
 
 /// @brief Parses a protocolInfo string (see renderProtocolInfo).
 ///
 /// @param protocolInfo the String from renderProtocolInfo.
 /// @return Protocol (i.e. http-get).
-std::string_view getProtocol(std::string_view protocolInfo);
+std::string getProtocol(const std::string& protocolInfo);
 
 /// @brief Adds escaping to special characters
 ///
