@@ -4,7 +4,7 @@
 
     web/config_load.cc - this file is part of Gerbera.
 
-    Copyright (C) 2020-2025 Gerbera Contributors
+    Copyright (C) 2020-2026 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -21,7 +21,7 @@
     $Id$
 */
 
-/// \file web/config_load.cc
+/// @file web/config_load.cc
 #define GRB_LOG_FAC GrbLogFacility::web
 
 #include "pages.h" // API
@@ -48,7 +48,6 @@
 #include "database/db_param.h"
 
 #include <fmt/chrono.h>
-#include <numeric>
 
 #define CONFIG_LOAD_AID "aid"
 #define CONFIG_LOAD_DEFAULTVALUE "defaultValue"
@@ -150,7 +149,11 @@ void Web::ConfigLoad::addNewValue(
 template <typename T>
 void Web::ConfigLoad::setValue(Json::Value& item, const T& value)
 {
+#if FMT_VERSION >= 120000
     static_assert(fmt::is_formattable<T, fmt::format_context>::value, "T must be formattable");
+#else
+    static_assert(fmt::has_formatter<T, fmt::format_context>::value, "T must be formattable");
+#endif
     item[CONFIG_LOAD_VALUE] = fmt::to_string(value);
 }
 
@@ -160,19 +163,13 @@ void Web::ConfigLoad::setValue(Json::Value& item, const std::string& value)
     item[CONFIG_LOAD_VALUE] = value;
 }
 
-template <>
-void Web::ConfigLoad::setValue(Json::Value& item, const std::string_view& value)
-{
-    item[CONFIG_LOAD_VALUE] = value.data();
-}
-
 template <>
 void Web::ConfigLoad::setValue(Json::Value& item, const fs::path& value)
 {
     item[CONFIG_LOAD_VALUE] = value.string();
 }
 
-/// \brief: process config_load request
+/// @brief process config_load request
 bool Web::ConfigLoad::processPageAction(Json::Value& element, const std::string& action)
 {
     Json::Value values;
@@ -215,7 +212,7 @@ bool Web::ConfigLoad::processPageAction(Json::Value& element, const std::string&
     return true;
 }
 
-/// \brief: write database status
+/// @brief write database status
 void Web::ConfigLoad::writeDatabaseStatus(Json::Value& values)
 {
     {
@@ -290,7 +287,7 @@ void Web::ConfigLoad::writeDatabaseStatus(Json::Value& values)
     }
 }
 
-/// \brief: write upnp shortcuts
+/// @brief write upnp shortcuts
 void Web::ConfigLoad::writeShortcuts(Json::Value& values)
 {
     auto shortcuts = database->getShortcuts();
@@ -306,7 +303,7 @@ void Web::ConfigLoad::writeShortcuts(Json::Value& values)
     }
 }
 
-/// \brief: write all values with simple type (string, int, bool)
+/// @brief write all values with simple type (string, int, bool)
 void Web::ConfigLoad::writeSimpleProperties(Json::Value& values)
 {
     for (auto&& option : ConfigOptionIterator()) {
@@ -320,7 +317,7 @@ void Web::ConfigLoad::writeSimpleProperties(Json::Value& values)
     }
 }
 
-/// \brief: write client configuration
+/// @brief write client configuration
 void Web::ConfigLoad::writeClientConfig(Json::Value& values)
 {
     // Output Clients
@@ -471,6 +468,11 @@ void Web::ConfigLoad::writeClientConfig(Json::Value& values)
                 cs->getItemPath(indexList, { ConfigVal::A_CLIENTS_GROUP, ConfigVal::A_CLIENTS_GROUP_NAME }),
                 cs->option, ConfigVal::A_CLIENTS_GROUP_NAME, group->getGroupName(), cs);
         }
+        {
+            addValue(values,
+                cs->getItemPath(indexList, { ConfigVal::A_CLIENTS_GROUP, ConfigVal::A_CLIENTS_GROUP_ALLOWED }),
+                cs->option, ConfigVal::A_CLIENTS_GROUP_ALLOWED, group->getAllowed(), cs);
+        }
         auto forbiddenDirs = group->getForbiddenDirectories();
         for (std::size_t j = 0; j < forbiddenDirs.size(); j++) {
             std::vector<std::size_t> subIndexList = { i, j };
@@ -483,12 +485,15 @@ void Web::ConfigLoad::writeClientConfig(Json::Value& values)
     addNewValue(values,
         cs->getItemPath(ITEM_PATH_NEW, { ConfigVal::A_CLIENTS_GROUP, ConfigVal::A_CLIENTS_GROUP_NAME }),
         cs->option, ConfigVal::A_CLIENTS_GROUP_NAME, definition->findConfigSetup(ConfigVal::A_CLIENTS_GROUP_NAME));
+    addNewValue(values,
+        cs->getItemPath(ITEM_PATH_NEW, { ConfigVal::A_CLIENTS_GROUP, ConfigVal::A_CLIENTS_GROUP_ALLOWED }),
+        cs->option, ConfigVal::A_CLIENTS_GROUP_ALLOWED, definition->findConfigSetup(ConfigVal::A_CLIENTS_GROUP_ALLOWED));
     addNewValue(values,
         cs->getItemPath(ITEM_PATH_NEW, { ConfigVal::A_CLIENTS_GROUP, ConfigVal::A_CLIENTS_GROUP_LOCATION }),
         cs->option, ConfigVal::A_CLIENTS_GROUP_LOCATION, definition->findConfigSetup(ConfigVal::A_CLIENTS_GROUP_LOCATION));
 }
 
-/// \brief: write import tweaks
+/// @brief write import tweaks
 void Web::ConfigLoad::writeImportTweaks(Json::Value& values)
 {
     auto cs = definition->findConfigSetup(ConfigVal::IMPORT_DIRECTORIES_LIST);
@@ -567,7 +572,7 @@ void Web::ConfigLoad::writeImportTweaks(Json::Value& values)
         cs->option, ConfigVal::A_DIRECTORIES_TWEAK_METAFILE_FILE);
 }
 
-/// \brief: write dynamic content
+/// @brief write dynamic content
 void Web::ConfigLoad::writeDynamicContent(Json::Value& values)
 {
     auto cs = definition->findConfigSetup(ConfigVal::SERVER_DYNAMIC_CONTENT_LIST);
@@ -622,7 +627,7 @@ void Web::ConfigLoad::writeDynamicContent(Json::Value& values)
         cs->option, ConfigVal::A_DYNAMIC_CONTAINER_UPNP_SHORTCUT, definition->findConfigSetup(ConfigVal::A_DYNAMIC_CONTAINER_UPNP_SHORTCUT));
 }
 
-/// \brief: write box layout
+/// @brief write box layout
 void Web::ConfigLoad::writeBoxLayout(Json::Value& values)
 {
     auto cs = definition->findConfigSetup(ConfigVal::BOXLAYOUT_LIST);
@@ -647,6 +652,9 @@ void Web::ConfigLoad::writeBoxLayout(Json::Value& values)
         addValue(values,
             cs->getItemPath(indexList, { ConfigVal::A_BOXLAYOUT_BOX, ConfigVal::A_BOXLAYOUT_BOX_ENABLED }),
             cs->option, ConfigVal::A_BOXLAYOUT_BOX_ENABLED, cont->getEnabled());
+        addValue(values,
+            cs->getItemPath(indexList, { ConfigVal::A_BOXLAYOUT_BOX, ConfigVal::A_BOXLAYOUT_BOX_SEARCHABLE }),
+            cs->option, ConfigVal::A_BOXLAYOUT_BOX_SEARCHABLE, cont->getSearchable());
         addValue(values,
             cs->getItemPath(indexList, { ConfigVal::A_BOXLAYOUT_BOX, ConfigVal::A_BOXLAYOUT_BOX_UPNP_SHORTCUT }),
             cs->option, ConfigVal::A_BOXLAYOUT_BOX_UPNP_SHORTCUT, cont->getUpnpShortcut());
@@ -667,10 +675,10 @@ void Web::ConfigLoad::writeBoxLayout(Json::Value& values)
             for (auto&& [key, value] : link) {
                 indexList = { i, j, k };
                 addValue(values,
-                    cs->getItemPath(indexList, { ConfigVal::A_BOXLAYOUT_CHAIN, ConfigVal::A_BOXLAYOUT_CHAIN_LINKS, ConfigVal::A_BOXLAYOUT_CHAIN_LINK }, ConfigBoxLayoutSetup::linkKey.data()),
+                    cs->getItemPath(indexList, { ConfigVal::A_BOXLAYOUT_CHAIN, ConfigVal::A_BOXLAYOUT_CHAIN_LINKS, ConfigVal::A_BOXLAYOUT_CHAIN_LINK }, ConfigBoxLayoutSetup::linkKey),
                     cs->option, ConfigVal::A_BOXLAYOUT_CHAIN_LINK, key);
                 addValue(values,
-                    cs->getItemPath(indexList, { ConfigVal::A_BOXLAYOUT_CHAIN, ConfigVal::A_BOXLAYOUT_CHAIN_LINKS, ConfigVal::A_BOXLAYOUT_CHAIN_LINK }, ConfigBoxLayoutSetup::linkValue.data()),
+                    cs->getItemPath(indexList, { ConfigVal::A_BOXLAYOUT_CHAIN, ConfigVal::A_BOXLAYOUT_CHAIN_LINKS, ConfigVal::A_BOXLAYOUT_CHAIN_LINK }, ConfigBoxLayoutSetup::linkValue),
                     cs->option, ConfigVal::A_BOXLAYOUT_CHAIN_LINK, value);
                 k++;
             }
@@ -702,15 +710,15 @@ void Web::ConfigLoad::writeBoxLayout(Json::Value& values)
         cs->option, ConfigVal::A_BOXLAYOUT_CHAIN_TYPE, definition->findConfigSetup(ConfigVal::A_BOXLAYOUT_CHAIN_TYPE));
 
     addNewValue(values,
-        cs->getItemPath(ITEM_PATH_NEW, { ConfigVal::A_BOXLAYOUT_CHAIN, ConfigVal::A_BOXLAYOUT_CHAIN_LINKS, ConfigVal::A_BOXLAYOUT_CHAIN_LINK }, ConfigBoxLayoutSetup::linkKey.data()),
+        cs->getItemPath(ITEM_PATH_NEW, { ConfigVal::A_BOXLAYOUT_CHAIN, ConfigVal::A_BOXLAYOUT_CHAIN_LINKS, ConfigVal::A_BOXLAYOUT_CHAIN_LINK }, ConfigBoxLayoutSetup::linkKey),
         cs->option, ConfigVal::A_BOXLAYOUT_CHAIN_LINK, definition->findConfigSetup(ConfigVal::A_BOXLAYOUT_CHAIN_LINK));
 
     addNewValue(values,
-        cs->getItemPath(ITEM_PATH_NEW, { ConfigVal::A_BOXLAYOUT_CHAIN, ConfigVal::A_BOXLAYOUT_CHAIN_LINKS, ConfigVal::A_BOXLAYOUT_CHAIN_LINK }, ConfigBoxLayoutSetup::linkValue.data()),
+        cs->getItemPath(ITEM_PATH_NEW, { ConfigVal::A_BOXLAYOUT_CHAIN, ConfigVal::A_BOXLAYOUT_CHAIN_LINKS, ConfigVal::A_BOXLAYOUT_CHAIN_LINK }, ConfigBoxLayoutSetup::linkValue),
         cs->option, ConfigVal::A_BOXLAYOUT_CHAIN_LINK, definition->findConfigSetup(ConfigVal::A_BOXLAYOUT_CHAIN_LINK));
 }
 
-/// \brief: write transconding configuration
+/// @brief write transconding configuration
 void Web::ConfigLoad::writeTranscoding(Json::Value& values)
 {
     auto cs = definition->findConfigSetup(ConfigVal::TRANSCODING_PROFILE_LIST);
@@ -736,6 +744,9 @@ void Web::ConfigLoad::writeTranscoding(Json::Value& values)
         addValue(values,
             cs->getItemPath(indexList, { ConfigVal::A_TRANSCODING_MIMETYPE_FILTER, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_CLIENTFLAGS }),
             cs->option, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_CLIENTFLAGS, ClientConfig::mapFlags(filter->getClientFlags()), cs);
+        addValue(values,
+            cs->getItemPath(indexList, { ConfigVal::A_TRANSCODING_MIMETYPE_FILTER, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_CLIENTFLAGS }),
+            cs->option, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_CLIENTWITHOUT, filter->matchesWithOut(), cs);
 
         if (filter->getTranscodingProfile())
             profiles[filter->getTranscodingProfile()->getName()] = filter->getTranscodingProfile();
@@ -755,6 +766,9 @@ void Web::ConfigLoad::writeTranscoding(Json::Value& values)
         addValue(values,
             cs->getItemPath(indexList, { ConfigVal::A_TRANSCODING_PROFILES_PROFLE, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_CLIENTFLAGS }),
             cs->option, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_CLIENTFLAGS, ClientConfig::mapFlags(entry->getClientFlags()));
+        addValue(values,
+            cs->getItemPath(indexList, { ConfigVal::A_TRANSCODING_PROFILES_PROFLE, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_CLIENTWITHOUT }),
+            cs->option, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_CLIENTWITHOUT, entry->matchesWithOut(), cs);
         addValue(values,
             cs->getItemPath(indexList, { ConfigVal::A_TRANSCODING_PROFILES_PROFLE, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_ENABLED }),
             cs->option, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_ENABLED, entry->isEnabled());
@@ -821,14 +835,14 @@ void Web::ConfigLoad::writeTranscoding(Json::Value& values)
                 addValue(values,
                     cs->getItemPath(indexList, { ConfigVal::A_TRANSCODING_PROFILES_PROFLE, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_AVI4CC, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_AVI4CC_4CC }),
                     cs->option, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_AVI4CC_4CC,
-                    std::accumulate(next(fourCCList.begin()), fourCCList.end(), fourCCList[0], [](auto&& a, auto&& b) { return fmt::format("{}, {}", a, b); }));
+                    fmt::format("{}", fmt::join(fourCCList, ", ")));
             }
         }
         pr++;
     }
 }
 
-/// \brief: write autoscan configuration
+/// @brief write autoscan configuration
 void Web::ConfigLoad::writeAutoscan(Json::Value& values)
 {
     for (auto&& ascs : definition->getConfigSetupList<ConfigAutoscanSetup>()) {
@@ -964,7 +978,7 @@ void Web::ConfigLoad::writeAutoscan(Json::Value& values)
     }
 }
 
-/// \brief: write content of all dictionaries
+/// @brief write content of all dictionaries
 void Web::ConfigLoad::writeDictionaries(Json::Value& values)
 {
     for (auto&& dcs : definition->getConfigSetupList<ConfigDictionarySetup>()) {
@@ -982,7 +996,7 @@ void Web::ConfigLoad::writeDictionaries(Json::Value& values)
     }
 }
 
-/// \brief: write content of all vectors
+/// @brief write content of all vectors
 void Web::ConfigLoad::writeVectors(Json::Value& values)
 {
     for (auto&& vcs : definition->getConfigSetupList<ConfigVectorSetup>()) {
@@ -1006,7 +1020,7 @@ void Web::ConfigLoad::writeVectors(Json::Value& values)
     }
 }
 
-/// \brief: write content of all arrays
+/// @brief write content of all arrays
 void Web::ConfigLoad::writeArrays(Json::Value& values)
 {
     for (auto&& acs : definition->getConfigSetupList<ConfigArraySetup>()) {
@@ -1023,7 +1037,7 @@ void Web::ConfigLoad::writeArrays(Json::Value& values)
     }
 }
 
-/// \brief: update entries with datebase values
+/// @brief update entries with datebase values
 void Web::ConfigLoad::updateEntriesFromDatabase(Json::Value& element, Json::Value& values)
 {
     for (auto&& entry : dbEntries) {
