@@ -4,7 +4,7 @@
 
     web/page_request.cc - this file is part of Gerbera.
 
-    Copyright (C) 2025 Gerbera Contributors
+    Copyright (C) 2025-2026 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -30,9 +30,6 @@
 
 #include "util/grb_fs.h"
 
-#include <chrono>
-#include <vector>
-
 // forward declarations
 class AutoscanDirectory;
 class CdsItemExternalURL;
